@@ -88,8 +88,8 @@ package Net::BitTorrent::Protocol::BEP03::Packets;
 
     sub build_bitfield ($) {
         my ($bitfield) = @_;
-        $bitfield = pack 'b*', $bitfield->to_Bin if blessed $bitfield;
-        if ((!$bitfield) || (unpack('b*', $bitfield) !~ m[^[01]+$])) {
+        $bitfield = pack 'B*', $bitfield->to_Bin if blessed $bitfield;
+        if ((!$bitfield) || (unpack('B*', $bitfield) !~ m[^[01]+$])) {
             carp sprintf 'Malformed bitfield passed to %s::build_bitfield()',
                 __PACKAGE__;
             return;
@@ -820,6 +820,6 @@ L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/u
 Neither this module nor the L<Author|/Author> is affiliated with BitTorrent,
 Inc.
 
-=for rcs $Id: Packets.pm f1e1d47 2010-07-24 02:23:43Z sanko@cpan.org $
+=for rcs $Id: Packets.pm 3d1f72b 2010-08-27 04:09:53Z sanko@cpan.org $
 
 =cut
