@@ -14,7 +14,13 @@ package Net::BitTorrent::Types;
                 NBTypes::Tracker::UDP NBTypes::Tracker::HTTP
                 NBTypes::Tracker::HTTP::Event]
         ],
-        file    => [qw[NBTypes::File::Open::Permission]],
+        file => [
+            qw[NBTypes::File::Open::Permission
+                NBTypes::File::Path
+                NBTypes::File::Path::Absolute
+                NBTypes::File::Path::PreExisting
+                ]
+        ],
         client  => [qw[NBTypes::Client::PeerID]],
         dht     => [qw[NBTypes::DHT::NodeID]],
         bencode => [qw[NBTypes::Bencode NBTypes::Bdecode]],
@@ -90,7 +96,19 @@ package Net::BitTorrent::Types;
     enum 'NBTypes::Tracker::HTTP::Event' => qw[started stopped completed];
 
     #
-    enum 'NBTypes::File::Open::Permission' => qw[ro wo rw];
+    enum 'NBTypes::File::Open::Permission'  => qw[ro wo rw];
+    subtype 'NBTypes::File::Path'           => as 'Str';
+    subtype 'NBTypes::File::Path::Absolute' => as 'Str' =>
+        where { require File::Spec; File::Spec->file_name_is_absolute($_) } =>
+        message {'Filename must be absolute.'};
+    coerce 'NBTypes::File::Path::Absolute' => from 'Str' =>
+        via { require File::Spec; File::Spec->rel2abs($_); };
+    subtype 'NBTypes::File::Path::PreExisting' => as 'Str' =>
+        where { require File::Spec; File::Spec->file_name_is_absolute($_) } =>
+        message {'Filename must be absolute.'} => where { -f $_ } =>
+        message {'File must be preexisting'};
+    coerce 'NBTypes::File::Path::PreExisting' => from 'Str' =>
+        via { require File::Spec; File::Spec->rel2abs($_); };
 
     #
     subtype 'NBTypes::Client::PeerID' => as 'Str' =>
@@ -164,6 +182,6 @@ L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/u
 Neither this module nor the L<Author|/Author> is affiliated with BitTorrent,
 Inc.
 
-=for rcs $Id: Types.pm 62b27d0 2010-09-05 04:22:11Z sanko@cpan.org $
+=for rcs $Id: Types.pm e9628b1 2010-09-12 03:10:17Z sanko@cpan.org $
 
 =cut
